Command class abstract

command class is the interface communication class and application.

Constructors

Command()

Properties

command → String
command is the identified what is the receive data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(Uint8List data) → void
this method is called with received data from the communication class.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited