CommunicateDataTcp class

Constructors

CommunicateDataTcp({required Socket connection, required int dataSize})

Properties

connection → Socket
final
dataSize → int
final
hashCode → int
The hash code for this object.
no setterinherited
receiveData → CommunicateData<Socket>?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isReceivedAll() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receive(Uint8List data) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited